# This module is automatically generated by autogen.sh. DO NOT EDIT.

from diagrams import Node
from pathlib import Path

class _DigitalOcean(Node):
    _type = "digitalocean"
    _icon_dir = Path(__file__).parent.parent.parent / "resources/digitalocean"


class Project(_DigitalOcean):
    _icon = "project.png"

# Aliases
