# This module is automatically generated by autogen.sh. DO NOT EDIT.

from diagrams import Node
from pathlib import Path

class _DNSProviders(Node):
    _type = "dnsproviders"
    _icon_dir = Path(__file__).parent.parent.parent / "resources/dnsproviders"



# Aliases
