# This module is automatically generated by autogen.sh. DO NOT EDIT.

from diagrams import Node
from pathlib import Path

class _Generic(Node):
    _type = "generic"
    _icon_dir = Path(__file__).parent.parent.parent / "resources/generic"


class Github(_Generic):
    _icon = "github.png"
class Jira(_Generic):
    _icon = "jira.png"
class Report_Portal(_Generic):
    _icon = "report_portal.png"
class Software_Engineer(_Generic):
    _icon = "software_engineer.png"

# Aliases
