# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _DNSProviders
from pathlib import Path

class _Namecheap(_DNSProviders):
    _type = "namecheap"
    _icon_dir = Path(__file__).parent.parent.parent / "resources/dnsproviders/namecheap"


class Namecheap_Api(_Namecheap):
    _icon = "namecheap_api.png"
class Namecheap_Domain(_Namecheap):
    _icon = "namecheap_domain.png"
class Provider(_Namecheap):
    _icon = "provider.png"

# Aliases
